@@ -86,7 +86,6 @@ static const PkEnumMatch enum_status_icon_name[] = {
 	{PK_STATUS_ENUM_REMOVE,			"pk-package-delete"},
 	{PK_STATUS_ENUM_REPACKAGING,		"pk-package-cleanup"},
 	{PK_STATUS_ENUM_REQUEST,		"pk-package-search"},
-	{PK_STATUS_ENUM_ROLLBACK,		"pk-package-info"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_RUNNING,		"pk-setup"},
 	{PK_STATUS_ENUM_SCAN_APPLICATIONS,	"pk-package-search"}, /* TODO: need better icon */
 	{PK_STATUS_ENUM_SETUP,			"pk-setup"},
@@ -127,7 +126,6 @@ static const PkEnumMatch enum_status_animation[] = {
 	{PK_STATUS_ENUM_REMOVE,			"pk-action-removing"},
 	{PK_STATUS_ENUM_REPACKAGING,		"pk-package-info"},
 	{PK_STATUS_ENUM_REQUEST,		"process-working"},
-	{PK_STATUS_ENUM_ROLLBACK,		"pk-action-removing"},
 	{PK_STATUS_ENUM_RUNNING,		"pk-setup"},
 	{PK_STATUS_ENUM_SCAN_APPLICATIONS,	"pk-action-searching"},
 	{PK_STATUS_ENUM_SETUP,			"pk-package-info"},
@@ -166,7 +164,6 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_REPO_ENABLE,		"pk-package-sources"},
 	{PK_ROLE_ENUM_REPO_SET_DATA,		"pk-package-sources"},
 	{PK_ROLE_ENUM_RESOLVE,			"pk-package-search"},
-	{PK_ROLE_ENUM_ROLLBACK,			"pk-rollback"},
 	{PK_ROLE_ENUM_SEARCH_DETAILS,		"pk-package-search"},
 	{PK_ROLE_ENUM_SEARCH_FILE,		"pk-package-search"},
 	{PK_ROLE_ENUM_SEARCH_GROUP,		"pk-package-search"},
@@ -174,12 +171,7 @@ static const PkEnumMatch enum_role_icon_name[] = {
 	{PK_ROLE_ENUM_UPDATE_PACKAGES,		"pk-package-update"},
 	{PK_ROLE_ENUM_UPDATE_SYSTEM,		"system-software-update"},
 	{PK_ROLE_ENUM_WHAT_PROVIDES,		"pk-package-search"},
-	{PK_ROLE_ENUM_SIMULATE_INSTALL_FILES,	"pk-package-add"},
-	{PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES, "pk-package-add"},
-	{PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES,	"pk-package-delete"},
-	{PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES,	"pk-package-update"},
 	{PK_ROLE_ENUM_UPGRADE_SYSTEM,		"system-software-update"},
-	{PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM,	"system-software-update"},
 	{PK_ROLE_ENUM_REPAIR_SYSTEM,		"system-software-update"},
 	{0, NULL}
 };
@@ -254,7 +246,6 @@ static const PkEnumMatch enum_message_icon_name[] = {
 	{PK_MESSAGE_ENUM_BACKEND_ERROR,		"dialog-error"},
 	{PK_MESSAGE_ENUM_DAEMON_ERROR,		"dialog-error"},
 	{PK_MESSAGE_ENUM_CACHE_BEING_REBUILT,	"dialog-information"},
-	{PK_MESSAGE_ENUM_UNTRUSTED_PACKAGE,	"dialog-warning"},
 	{PK_MESSAGE_ENUM_NEWER_PACKAGE_EXISTS,	"dialog-information"},
 	{PK_MESSAGE_ENUM_COULD_NOT_FIND_PACKAGE,"dialog-error"},
 	{PK_MESSAGE_ENUM_CONFIG_FILES_CHANGED,	"dialog-information"},
@@ -502,6 +493,12 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 	case PK_ERROR_ENUM_CANCELLED_PRIORITY:
 		text = _("Rescheduled due to priority");
 		break;
+	case PK_ERROR_ENUM_UNFINISHED_TRANSACTION:
+		text = _("Unfinished transaction");
+		break;
+	case PK_ERROR_ENUM_LOCK_REQUIRED:
+		text = _("Lock required");
+		break;
 	default:
 		g_warning ("Unknown error");
 	}
@@ -750,9 +747,15 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 	case PK_ERROR_ENUM_CANNOT_FETCH_SOURCES:
 		text = _("The list of software sources could not be downloaded.");
 		break;
+	case PK_ERROR_ENUM_UNFINISHED_TRANSACTION:
+		text = _("A previous package management transaction was interrupted.");
+		break;
 	case PK_ERROR_ENUM_CANCELLED_PRIORITY:
 		text = _("The transaction has been canceled and will be retried when the system is idle.");
 		break;
+	case PK_ERROR_ENUM_LOCK_REQUIRED:
+		text = _("A package manager lock is required.");
+		break;
 	default:
 		g_warning ("Unknown error, please report a bug at " GPK_BUGZILLA_URL ".\n"
 			    "More information is available in the detailed report.");
@@ -879,9 +882,6 @@ gpk_message_enum_to_localised_text (PkMessageEnum message)
 	case PK_MESSAGE_ENUM_CACHE_BEING_REBUILT:
 		text = _("The package list cache is being rebuilt");
 		break;
-	case PK_MESSAGE_ENUM_UNTRUSTED_PACKAGE:
-		text = _("An untrusted package was installed");
-		break;
 	case PK_MESSAGE_ENUM_NEWER_PACKAGE_EXISTS:
 		text = _("A newer package exists");
 		break;
@@ -980,10 +980,6 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 		/* TRANSLATORS: transaction state, checking if we have all the security keys for the operation */
 		text = _("Checking signatures");
 		break;
-	case PK_STATUS_ENUM_ROLLBACK:
-		/* TRANSLATORS: transaction state, when we return to a previous system state */
-		text = _("Rolling back");
-		break;
 	case PK_STATUS_ENUM_TEST_COMMIT:
 		/* TRANSLATORS: transaction state, when we're doing a test transaction */
 		text = _("Testing changes");
@@ -1352,10 +1348,6 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Canceling");
 		break;
-	case PK_ROLE_ENUM_ROLLBACK:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Rolling back");
-		break;
 	case PK_ROLE_ENUM_GET_REPO_LIST:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting list of repositories");
@@ -1408,30 +1400,10 @@ gpk_role_enum_to_localised_present (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Getting old transactions");
 		break;
-	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the install of files");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the install");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the remove");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the update");
-		break;
 	case PK_ROLE_ENUM_UPGRADE_SYSTEM:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Upgrading system");
 		break;
-	case PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Simulating the system repair");
-		break;
 	case PK_ROLE_ENUM_REPAIR_SYSTEM:
 		/* TRANSLATORS: The role of the transaction, in present tense */
 		text = _("Repairing the system");
@@ -1520,10 +1492,6 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Canceled");
 		break;
-	case PK_ROLE_ENUM_ROLLBACK:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Rolled back");
-		break;
 	case PK_ROLE_ENUM_GET_REPO_LIST:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got list of repositories");
@@ -1576,30 +1544,10 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Got old transactions");
 		break;
-	case PK_ROLE_ENUM_SIMULATE_INSTALL_FILES:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the install of files");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_INSTALL_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the install");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_REMOVE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the remove");
-		break;
-	case PK_ROLE_ENUM_SIMULATE_UPDATE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the update");
-		break;
 	case PK_ROLE_ENUM_UPGRADE_SYSTEM:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Upgraded system");
 		break;
-	case PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM:
-		/* TRANSLATORS: The role of the transaction, in past tense */
-		text = _("Simulated the system repair");
-		break;
 	case PK_ROLE_ENUM_REPAIR_SYSTEM:
 		/* TRANSLATORS: The role of the transaction, in past tense */
 		text = _("Repaired the system");
